﻿local RSwapper3 = LibStub("AceAddon-3.0"):GetAddon("RSwapper3");
local L = LibStub("AceLocale-3.0"):GetLocale("RSwapper3", true);

local RS3GUI = RSwapper3.RS3GUI;

local TabFrame = RS3GUI.TabFrame;
local WeaponFrame = RS3GUI.SubFrame[1];
local OptionsFrame = RS3GUI.SubFrame[2];

function WeaponFrame:DoInit()
	WeaponFrame.DidInit = true;
	
	WeaponFrame:SetFrameStrata("MEDIUM");
	WeaponFrame:SetWidth(RS3GUI.Width);
	WeaponFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile = true, tileSize = 32, edgeSize = 32, 
			insets = { left = 8, right = 8, top = 8, bottom = 8 }
		});
	WeaponFrame:SetBackdropColor(0,0,0,1);
	WeaponFrame:EnableMouse();
	WeaponFrame:SetPoint("TOPLEFT", TabFrame, "BOTTOMLEFT", 0, 12);
	
	WeaponFrame.Instructions = WeaponFrame:CreateFontString("$parent_Instructions","OVERLAY","GameFontNormal");
	WeaponFrame.Instructions:SetPoint("TOPLEFT", WeaponFrame, "TOPLEFT", 13, -13);
	WeaponFrame.Instructions:SetWidth(RS3GUI.Width - 26);
	WeaponFrame.Instructions:SetText(L["Drag items into the slots below to set your weapons. The \"Sword\" slots are for weapons to use when not stealthed, and do not need to be swords. The Off Hand slots are optional, and may be cleared by Right Clicking."]);
	WeaponFrame.Instructions:SetTextColor(0.2235, 0.6549, 0.8745);
	WeaponFrame.Instructions:SetJustifyH("LEFT");
	
	WeaponFrame.WeaponList = {};

	WeaponFrame:AddWeaponLine(WeaponFrame.WeaponList, L["Dagger"] .. ": ", "Dagger", "ODagger", true);
	WeaponFrame:AddWeaponLine(WeaponFrame.WeaponList, L["Sword"] .. ": ", "Sword", "OSword");
end

function WeaponFrame:AddWeaponLine(list, label, value, ovalue, first)
	local index = (#list) + 1;
	
	local WpnLine = {};
	WpnLine.Value = value;
	WpnLine.OValue = ovalue;
	
	WpnLine.Label = WeaponFrame:CreateFontString("$parent_WpnLabel" .. index, "ARTWORK", "GameFontNormal");
	WpnLine.Button = CreateFrame("Button", nil, WeaponFrame);
	WpnLine.OButton = CreateFrame("Button", nil, WeaponFrame);
	
	if (first) then
		WpnLine.Label:SetPoint("TOPLEFT", WeaponFrame.Instructions, "BOTTOMLEFT", 0, -5);
	else
		WpnLine.Label:SetPoint("TOPLEFT", list[index-1].Label, "BOTTOMLEFT", 0, -5);
	end
	WpnLine.Label:SetText(label);
	WpnLine.Label:SetJustifyH("LEFT");
	WpnLine.Label:SetJustifyV("MIDDLE");
	WpnLine.Label:SetHeight(37);
		
	WpnLine.Button:SetPoint("TOPLEFT", WpnLine.Label, "TOPRIGHT");
	WpnLine.Button:EnableMouse();
	WpnLine.Button:RegisterForClicks("LeftButtonUp", "RightButtonUp");
	WpnLine.Button:RegisterForDrag("LeftButton");
	WpnLine.Button:SetHeight(37);
	WpnLine.Button:SetWidth(37);
	
	WpnLine.OButton:SetPoint("TOPLEFT", WpnLine.Button, "TOPRIGHT");
	WpnLine.OButton:EnableMouse();
	WpnLine.OButton:RegisterForClicks("LeftButtonUp", "RightButtonUp");
	WpnLine.OButton:RegisterForDrag("LeftButton");
	WpnLine.OButton:SetHeight(37);
	WpnLine.OButton:SetWidth(37);
	
	WpnLine.Button:SetScript("OnDragStart", function(self, button)
			if (RSwapper3.db.char[value]) then
				PickupItem(RSwapper3.db.char[value]);
			end
		end);
	WpnLine.Button:SetScript("OnReceiveDrag", function(self, button)
			local itemtype, subtype, link, _;
			itemtype, _, link = GetCursorInfo();
			if (itemtype == "item") then
				_, _, _, _, _, itemtype, subtype = GetItemInfo(link);
				if ((itemtype == RSwapper3.LWEAPON) and (subtype ~= RSwapper3.LFISHINGPOLES)) then
					ClearCursor();
					RSwapper3.db.char[value] = link;
					WeaponFrame:DoUpdate();
				end
			end
		end);
	WpnLine.Button:SetScript("OnClick", function(self, button)
			if (button == "LeftButton") then
				local itemtype, subtype, link, _;
				itemtype, _, link = GetCursorInfo();
				if (itemtype == "item") then
					_, _, _, _, _, itemtype, subtype = GetItemInfo(link);
					if ((itemtype == RSwapper3.LWEAPON) and (subtype ~= RSwapper3.LFISHINGPOLES)) then
						ClearCursor();
						RSwapper3.db.char[value] = link;
						WeaponFrame:DoUpdate();
					end
				end
			end
		end);
	WpnLine.Button:SetScript("OnEnter", function()
			GameTooltip:SetOwner(WeaponFrame, "ANCHOR_NONE");
			GameTooltip:SetPoint("TOPLEFT", WeaponFrame, "TOPRIGHT");
			GameTooltip:ClearLines();
			if (RSwapper3.db.char[value]) then
				GameTooltip:SetHyperlink(RSwapper3.db.char[value]);
			else
				GameTooltip:AddLine(L["|cffff0000[Not Set]|r"]);
			end
			GameTooltip:Show();
		end);
	WpnLine.Button:SetScript("OnLeave", function()
			GameTooltip:Hide();
		end);

	WpnLine.OButton:SetScript("OnDragStart", function(self, button)
			if (RSwapper3.db.char[ovalue]) then
				PickupItem(RSwapper3.db.char[ovalue]);
			end
		end);
	WpnLine.OButton:SetScript("OnReceiveDrag", function(self, button)
			local itemtype, subtype, link, _;
			itemtype, _, link = GetCursorInfo();
			if (itemtype == "item") then
				_, _, _, _, _, itemtype, subtype = GetItemInfo(link);
				if ((itemtype == RSwapper3.LWEAPON) and (subtype ~= RSwapper3.LFISHINGPOLES)) then
					ClearCursor();
					RSwapper3.db.char[ovalue] = link;
					WeaponFrame:DoUpdate();
				end
			end
		end);
	WpnLine.OButton:SetScript("OnClick", function(self, button)
			if (button == "LeftButton") then
				local itemtype, subtype, link, _;
				itemtype, _, link = GetCursorInfo();
				if (itemtype == "item") then
					_, _, _, _, _, itemtype, subtype = GetItemInfo(link);
					if ((itemtype == RSwapper3.LWEAPON) and (subtype ~= RSwapper3.LFISHINGPOLES)) then
						ClearCursor();
						RSwapper3.db.char[ovalue] = link;
						WeaponFrame:DoUpdate();
					end
				end
			elseif (button == "RightButton") then
				RSwapper3.db.char[ovalue] = nil;
				WeaponFrame:DoUpdate();
			end
		end);
	WpnLine.OButton:SetScript("OnEnter", function()
			GameTooltip:SetOwner(WeaponFrame, "ANCHOR_NONE");
			GameTooltip:SetPoint("TOPLEFT", WeaponFrame, "TOPRIGHT");
			GameTooltip:ClearLines();
			if (RSwapper3.db.char[ovalue]) then
				GameTooltip:SetHyperlink(RSwapper3.db.char[ovalue]);
			else
				GameTooltip:AddLine(L["|cffff0000[Not Set]|r"]);
			end
			GameTooltip:Show();
		end);
	WpnLine.OButton:SetScript("OnLeave", function()
			GameTooltip:Hide();
		end);
		
	list[index] = WpnLine;
end

function WeaponFrame:DoUpdate()
	local frameheight = 18 + WeaponFrame.Instructions:GetHeight();
	for i, wpn in ipairs(WeaponFrame.WeaponList) do
		if (RSwapper3.db.char[wpn.Value]) then
			wpn.Button:SetNormalTexture(GetItemIcon(RSwapper3.db.char[wpn.Value]));
		else
			wpn.Button:SetNormalTexture(select(2, GetInventorySlotInfo("MAINHANDSLOT")));
		end
		if (RSwapper3.db.char[wpn.OValue]) then
			wpn.OButton:SetNormalTexture(GetItemIcon(RSwapper3.db.char[wpn.OValue]));
		else
			wpn.OButton:SetNormalTexture(select(2, GetInventorySlotInfo("SECONDARYHANDSLOT")));
		end
		frameheight = frameheight + 42;
	end
	WeaponFrame:SetHeight(frameheight + 8);
end